#line 2 "scan.c"

#line 4 "scan.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart (FILE *input_file  );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size  );
void yy_delete_buffer (YY_BUFFER_STATE b  );
void yy_flush_buffer (YY_BUFFER_STATE b  );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state (void );

static void yyensure_buffer_stack (void );
static void yy_load_buffer_state (void );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,int len  );

void *yyalloc (yy_size_t  );
void *yyrealloc (void *,yy_size_t  );
void yyfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *yyin = (FILE *) 0, *yyout = (FILE *) 0;

typedef int yy_state_type;

extern int yylineno;

int yylineno = 1;

extern char *yytext;
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 96
#define YY_END_OF_BUFFER 97
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[387] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,   97,   95,
       86,   86,   94,   87,   84,   95,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   96,   96,   96,
       89,   90,   86,   94,   84,   92,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   34,   85,   85,   85,   85,   85,
       85,   85,   85,   44,   85,   85,   85,   49,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,    0,    0,

        0,   89,   88,   92,    3,   85,    5,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   28,   85,   85,
       85,   85,   36,   85,   85,   39,   85,   85,   85,   43,
       85,   46,   47,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   65,   85,   67,
       85,   85,   85,   85,   85,   85,   85,   85,   77,   85,
       85,   85,   85,   85,   83,   93,    0,    0,   91,   85,
       85,   85,   85,   85,   85,   85,   85,   15,   85,   17,
       85,   18,   19,   85,   85,   85,   23,   85,   85,   85,

       85,   85,   85,   31,   85,   85,   35,   85,   38,   85,
       41,   42,   45,   48,   50,   85,   52,   85,   85,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   85,   72,   85,   85,   76,   85,   85,   85,
       85,   82,   93,   93,    4,   85,   85,    8,   85,   85,
       85,   85,   85,   85,   85,   20,   21,   85,   85,   25,
       85,   85,   85,   85,   32,   85,   85,   85,   40,   85,
       85,   85,   85,   85,   85,   85,   85,   85,   85,   85,
       85,   66,   68,   85,   85,   85,   73,   85,   85,   85,
       85,   85,    6,    7,   85,   85,   11,   85,   85,   85,

       16,    2,   85,   85,   85,   27,   29,   85,   85,   85,
       37,   51,   85,   85,   85,   85,   57,   85,   85,   60,
       85,   85,   64,   85,   85,   71,   74,   85,   85,   79,
       85,   81,    9,   10,   85,   85,   85,    2,   22,   85,
       85,   30,   85,    1,   53,   85,   85,   85,   58,   85,
       61,   85,   85,   70,   75,   85,   85,   85,   13,   85,
       24,   26,   85,    1,   54,   85,   56,   85,   62,   85,
       85,   85,   12,   14,   33,   55,   85,   63,   69,   78,
       85,   85,   85,   59,   80,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    2,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    5,    6,    1,    1,    7,    1,
        1,    1,    1,    1,    1,    1,    1,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    1,    9,   10,
        1,   11,    1,   12,   13,   14,   15,   16,   17,   18,
       19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   36,   37,   22,
        1,    1,    1,    1,   22,    1,   38,   39,   40,   41,

       42,   43,   44,   45,   46,   22,   47,   48,   49,   50,
       51,   52,   53,   54,   55,   56,   57,   58,   59,   60,
       61,   22,    1,    1,    1,    1,    1,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,

       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22
    } ;

static yyconst flex_int32_t yy_meta[62] =
    {   0,
        1,    2,    3,    3,    1,    4,    5,    4,    1,    1,
        6,    1,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7
    } ;

static yyconst flex_int16_t yy_base[398] =
    {   0,
        0,    0,  155,  147,   61,   73,  136,  106,  111,  891,
       84,   87,    0,  891,  101,    0,   76,   80,   71,   90,
       93,  121,    0,   80,   93,  110,   99,  147,  181,  125,
       79,   97,  221,  156,  140,  102,  128,  891,    0,  178,
        0,   97,  193,    0,   94,    0,    0,  159,  125,  131,
      182,  191,  141,  120,  144,  161,  173,  171,  204,  205,
      238,  218,  183,  231,    0,  249,  211,  218,  252,  222,
      241,  258,  250,  249,  269,  272,  270,  269,  273,  265,
      281,  287,  287,  274,  305,  284,  281,  279,  326,  290,
      288,  308,  299,  313,  331,  315,  322,  302,   86,  369,

      378,    0,  891,    0,    0,  323,    0,  328,  343,  337,
      333,  342,  358,  346,  376,  373,  371,  366,  368,  369,
      371,  383,  368,  378,  372,  387,  384,  387,  385,  391,
      386,  379,    0,  381,  393,    0,  406,  411,  415,    0,
      421,    0,    0,  409,  405,  420,  423,  417,  413,  424,
      432,  438,  422,  431,  429,  425,  425,    0,  443,    0,
      432,  436,  455,  441,  460,  457,  467,  470,    0,  463,
      463,  459,  480,  464,    0,  499,   96,  519,  211,  480,
      474,  484,  477,  479,  482,  483,  496,    0,  483,    0,
      499,    0,    0,  497,  500,  500,    0,  509,  520,  514,

      510,  525,  530,  508,  514,  514,    0,  531,    0,  535,
        0,    0,    0,    0,    0,  532,    0,  541,  534,  537,
      538,  540,  553,  553,  544,  548,  558,  559,  553,  565,
      570,  570,  573,    0,  572,  566,    0,  563,  575,  581,
      565,    0,  600,  891,    0,  571,  574,    0,  591,  585,
      597,  593,  605,  607,  608,    0,    0,  596,  595,    0,
      618,  612,  602,  606,    0,  616,  622,  614,    0,  616,
      614,  629,  628,  614,  624,  625,  628,  629,  649,  641,
      639,    0,    0,  643,  643,  655,  646,  647,  649,  659,
      653,  669,    0,    0,  658,  657,    0,  667,  676,  664,

        0,  719,  682,  685,  682,    0,    0,  687,  682,  693,
        0,    0,  697,  698,  696,  701,    0,  693,  711,    0,
      698,  715,    0,  711,  703,    0,    0,  704,  724,    0,
      723,    0,    0,    0,  724,  717,  715,  744,    0,  720,
      735,    0,  728,  768,    0,  726,  742,  731,    0,  734,
        0,  748,  753,    0,    0,  749,  745,  760,    0,  742,
        0,    0,  750,  791,    0,  766,    0,  762,  755,  770,
      765,  770,    0,    0,    0,    0,  782,    0,    0,    0,
      784,  783,  785,    0,    0,  891,  827,  834,  841,  848,
       87,  852,  859,  865,  872,  876,  883

    } ;

static yyconst flex_int16_t yy_def[398] =
    {   0,
      386,    1,  387,  387,  388,  388,  389,  389,  386,  386,
      386,  386,  390,  386,  386,  391,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  386,  393,  394,
      395,  386,  386,  390,  386,  396,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  393,  397,

      394,  395,  386,  396,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  386,  397,  397,  397,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,

      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  386,  386,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,

      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  386,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  386,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,    0,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386

    } ;

static yyconst flex_int16_t yy_nxt[953] =
    {   0,
       10,   11,   12,   11,   13,   10,   14,   15,   10,   10,
       10,   16,   17,   18,   19,   20,   21,   22,   23,   23,
       24,   23,   25,   26,   27,   28,   29,   30,   31,   32,
       33,   34,   35,   23,   36,   23,   37,   17,   18,   19,
       20,   21,   22,   23,   23,   24,   25,   26,   27,   28,
       29,   30,   31,   32,   33,   34,   35,   23,   36,   23,
       37,   38,   38,   38,   38,   38,   38,   38,   38,   38,
       38,   38,   38,   38,   38,   38,   38,   38,   38,   38,
       38,   38,   38,   38,   38,   43,   43,   43,   43,   43,
       43,   48,   50,   46,   51,   65,  176,   52,  386,   49,

       53,   45,   54,  103,  179,   66,   55,   57,   45,   67,
      386,   82,   42,   83,   97,   70,   48,   50,   51,   56,
       65,   52,   58,   49,   53,   71,   59,   54,   60,   66,
       68,   55,   57,   61,   67,   82,   69,   80,   83,   97,
       70,   62,   42,   56,   98,  108,   58,   63,  107,   71,
       59,  116,   60,   64,   81,   68,   39,  115,   61,   72,
       69,  117,   80,   73,   39,   95,   62,   96,   92,   98,
      108,   63,  107,   74,  105,  116,   93,   64,   81,  100,
      100,  100,  115,  106,   72,   94,  117,  118,   73,   95,
      386,   96,  119,   92,   43,   43,   43,   74,   75,  105,

      120,   93,  109,  386,   76,   77,   78,  106,  110,   94,
       79,  118,  128,  386,  111,  112,  113,  119,  114,  179,
      121,  122,  386,   75,  120,  123,  386,  109,   76,   77,
       78,  386,  110,  386,   79,   84,  128,   85,  111,  112,
      113,  126,  114,  127,   86,  121,  122,  133,  134,   87,
      123,  137,   88,   89,  129,   90,  130,   91,  124,  386,
       84,  125,   85,  131,  141,  126,  135,  127,   86,  132,
      136,  133,  134,   87,  138,  137,   88,   89,  129,   90,
      130,   91,  139,  124,  140,  125,  142,  143,  131,  141,
      144,  135,  145,  146,  132,  136,  147,  148,  138,  150,

      159,  151,  386,  154,  160,  161,  139,  149,  140,  386,
      164,  142,  143,  165,  152,  144,  145,  153,  146,  155,
      147,  166,  148,  167,  150,  159,  151,  154,  160,  161,
      173,  149,  175,  156,  157,  164,  158,  165,  152,  162,
      163,  153,  174,  180,  155,  168,  166,  167,  386,  169,
      181,  170,  386,  386,  171,  173,  175,  156,  157,  182,
      158,  172,  183,  184,  162,  163,  185,  174,  180,  168,
      178,  100,  178,  169,  181,  186,  170,  179,  171,  100,
      100,  100,  188,  187,  182,  172,  183,  184,  189,  190,
      185,  191,  386,  192,  193,  194,  195,  196,  386,  197,

      186,  198,  199,  200,  201,  205,  188,  187,  204,  206,
      207,  202,  208,  189,  190,  209,  191,  192,  193,  194,
      195,  203,  196,  197,  210,  198,  199,  211,  200,  201,
      205,  212,  204,  206,  207,  202,  208,  213,  216,  209,
      214,  215,  217,  386,  218,  203,  219,  220,  221,  210,
      222,  225,  211,  223,  224,  226,  212,  227,  228,  229,
      386,  230,  213,  216,  214,  215,  231,  217,  218,  232,
      219,  220,  233,  221,  234,  222,  225,  223,  224,  226,
      235,  227,  228,  236,  229,  230,  237,  386,  238,  239,
      231,  240,  241,  248,  232,  242,  233,  386,  250,  234,

      243,  243,  243,  251,  235,  245,  246,  244,  236,  247,
      249,  237,  238,  239,  254,  240,  252,  241,  248,  242,
      178,  100,  178,  250,  255,  253,  256,  179,  251,  245,
      246,  257,  258,  247,  249,  259,  260,  263,  254,  261,
      262,  252,  264,  386,  265,  266,  267,  268,  255,  253,
      256,  269,  270,  271,  272,  257,  258,  273,  274,  259,
      275,  260,  263,  261,  262,  276,  277,  264,  265,  266,
      267,  278,  268,  279,  280,  281,  269,  270,  271,  272,
      282,  283,  273,  274,  284,  275,  285,  286,  287,  290,
      276,  277,  288,  289,  291,  278,  292,  279,  293,  280,

      281,  243,  243,  243,  282,  294,  283,  295,  244,  284,
      296,  285,  286,  287,  290,  297,  288,  289,  299,  291,
      292,  300,  293,  301,  302,  386,  298,  303,  304,  294,
      305,  306,  295,  307,  296,  308,  309,  310,  386,  311,
      297,  312,  299,  313,  314,  315,  300,  316,  301,  302,
      298,  303,  304,  317,  318,  305,  306,  307,  319,  308,
      320,  309,  310,  311,  321,  312,  322,  313,  323,  314,
      315,  316,  324,  325,  326,  386,  327,  317,  318,  328,
      329,  330,  319,  331,  320,  332,  386,  333,  334,  321,
      322,  335,  323,  336,  386,  337,  324,  325,  339,  326,

      327,  340,  342,  328,  329,  330,  341,  331,  343,  344,
      332,  333,  334,  345,  346,  335,  347,  348,  336,  337,
      338,  338,  338,  339,  349,  350,  340,  342,  351,  352,
      341,  353,  343,  354,  344,  355,  356,  357,  345,  346,
      358,  347,  348,  359,  360,  338,  338,  338,  349,  361,
      350,  362,  351,  363,  352,  365,  353,  354,  366,  355,
      367,  356,  357,  368,  369,  358,  370,  359,  360,  364,
      364,  364,  371,  361,  372,  373,  362,  363,  374,  365,
      375,  376,  377,  366,  367,  378,  379,  368,  380,  369,
      381,  370,  364,  364,  364,  382,  371,  383,  372,  384,

      373,  385,  374,  386,  375,  386,  376,  377,  386,  378,
      386,  379,  380,  386,  386,  381,  386,  386,  386,  386,
      382,  386,  383,  386,  384,  386,  385,   38,   38,   38,
       38,   38,   38,   38,   40,   40,   40,   40,   40,   40,
       40,   41,   41,   41,   41,   41,   41,   41,   44,   44,
      386,   44,   44,   44,   44,   47,  386,  386,   47,   99,
       99,   99,   99,   99,  386,   99,  101,  101,  101,  386,
      386,  101,  102,  102,  102,  102,  386,  102,  102,  104,
      386,  386,  104,  177,  177,  177,  177,  177,  177,  177,
        9,  386,  386,  386,  386,  386,  386,  386,  386,  386,

      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386
    } ;

static yyconst flex_int16_t yy_chk[953] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,   11,   11,   11,   12,   12,
       12,   17,   18,  391,   19,   24,   99,   19,  177,   17,

       19,   45,   20,   42,  177,   24,   20,   21,   15,   25,
        9,   31,    8,   32,   36,   27,   17,   18,   19,   20,
       24,   19,   21,   17,   19,   27,   21,   20,   21,   24,
       26,   20,   21,   22,   25,   31,   26,   30,   32,   36,
       27,   22,    7,   20,   37,   50,   21,   22,   49,   27,
       21,   54,   21,   22,   30,   26,    4,   53,   22,   28,
       26,   55,   30,   28,    3,   35,   22,   35,   34,   37,
       50,   22,   49,   28,   48,   54,   34,   22,   30,   40,
       40,   40,   53,   48,   28,   34,   55,   56,   28,   35,
        0,   35,   57,   34,   43,   43,   43,   28,   29,   48,

       58,   34,   51,    0,   29,   29,   29,   48,   51,   34,
       29,   56,   63,  179,   51,   52,   52,   57,   52,  179,
       59,   60,    0,   29,   58,   60,    0,   51,   29,   29,
       29,    0,   51,    0,   29,   33,   63,   33,   51,   52,
       52,   62,   52,   62,   33,   59,   60,   67,   68,   33,
       60,   70,   33,   33,   64,   33,   64,   33,   61,    0,
       33,   61,   33,   66,   74,   62,   69,   62,   33,   66,
       69,   67,   68,   33,   71,   70,   33,   33,   64,   33,
       64,   33,   72,   61,   73,   61,   75,   76,   66,   74,
       77,   69,   78,   79,   66,   69,   80,   81,   71,   82,

       86,   83,    0,   84,   87,   88,   72,   81,   73,    0,
       90,   75,   76,   91,   83,   77,   78,   83,   79,   85,
       80,   92,   81,   93,   82,   86,   83,   84,   87,   88,
       96,   81,   98,   85,   85,   90,   85,   91,   83,   89,
       89,   83,   97,  106,   85,   94,   92,   93,    0,   94,
      108,   95,    0,    0,   95,   96,   98,   85,   85,  109,
       85,   95,  110,  111,   89,   89,  112,   97,  106,   94,
      100,  100,  100,   94,  108,  113,   95,  100,   95,  101,
      101,  101,  114,  113,  109,   95,  110,  111,  115,  116,
      112,  117,    0,  118,  119,  120,  121,  122,    0,  123,

      113,  124,  125,  126,  127,  130,  114,  113,  129,  131,
      132,  128,  134,  115,  116,  135,  117,  118,  119,  120,
      121,  128,  122,  123,  137,  124,  125,  138,  126,  127,
      130,  139,  129,  131,  132,  128,  134,  141,  146,  135,
      144,  145,  147,    0,  148,  128,  149,  150,  151,  137,
      152,  154,  138,  153,  153,  155,  139,  156,  157,  159,
        0,  161,  141,  146,  144,  145,  162,  147,  148,  163,
      149,  150,  164,  151,  165,  152,  154,  153,  153,  155,
      166,  156,  157,  167,  159,  161,  168,    0,  170,  171,
      162,  172,  173,  183,  163,  174,  164,    0,  185,  165,

      176,  176,  176,  186,  166,  180,  181,  176,  167,  182,
      184,  168,  170,  171,  189,  172,  187,  173,  183,  174,
      178,  178,  178,  185,  191,  187,  194,  178,  186,  180,
      181,  195,  196,  182,  184,  198,  199,  202,  189,  200,
      201,  187,  203,    0,  204,  205,  206,  208,  191,  187,
      194,  210,  216,  218,  219,  195,  196,  220,  221,  198,
      222,  199,  202,  200,  201,  223,  224,  203,  204,  205,
      206,  225,  208,  226,  227,  228,  210,  216,  218,  219,
      229,  230,  220,  221,  231,  222,  232,  233,  235,  239,
      223,  224,  236,  238,  240,  225,  241,  226,  246,  227,

      228,  243,  243,  243,  229,  247,  230,  249,  243,  231,
      250,  232,  233,  235,  239,  251,  236,  238,  252,  240,
      241,  253,  246,  254,  255,    0,  251,  258,  259,  247,
      261,  262,  249,  263,  250,  264,  266,  267,    0,  268,
      251,  270,  252,  271,  272,  273,  253,  274,  254,  255,
      251,  258,  259,  275,  276,  261,  262,  263,  277,  264,
      278,  266,  267,  268,  279,  270,  280,  271,  281,  272,
      273,  274,  284,  285,  286,    0,  287,  275,  276,  288,
      289,  290,  277,  291,  278,  292,    0,  295,  296,  279,
      280,  298,  281,  299,    0,  300,  284,  285,  303,  286,

      287,  304,  308,  288,  289,  290,  305,  291,  309,  310,
      292,  295,  296,  313,  314,  298,  315,  316,  299,  300,
      302,  302,  302,  303,  318,  319,  304,  308,  321,  322,
      305,  324,  309,  325,  310,  328,  329,  331,  313,  314,
      335,  315,  316,  336,  337,  338,  338,  338,  318,  340,
      319,  341,  321,  343,  322,  346,  324,  325,  347,  328,
      348,  329,  331,  350,  352,  335,  353,  336,  337,  344,
      344,  344,  356,  340,  357,  358,  341,  343,  360,  346,
      363,  366,  368,  347,  348,  369,  370,  350,  371,  352,
      372,  353,  364,  364,  364,  377,  356,  381,  357,  382,

      358,  383,  360,    0,  363,    0,  366,  368,    0,  369,
        0,  370,  371,    0,    0,  372,    0,    0,    0,    0,
      377,    0,  381,    0,  382,    0,  383,  387,  387,  387,
      387,  387,  387,  387,  388,  388,  388,  388,  388,  388,
      388,  389,  389,  389,  389,  389,  389,  389,  390,  390,
        0,  390,  390,  390,  390,  392,    0,    0,  392,  393,
      393,  393,  393,  393,    0,  393,  394,  394,  394,    0,
        0,  394,  395,  395,  395,  395,    0,  395,  395,  396,
        0,    0,  396,  397,  397,  397,  397,  397,  397,  397,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,

      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386,  386,  386,  386,  386,  386,  386,  386,  386,
      386,  386
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[97] =
    {   0,
1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 1, 0, 1, 0, 0, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scan.l"
#line 2 "scan.l"
/*-------------------------------------------------------------------------
 * scan.l
 *
 *	Flex keyword and token scanner for slonik
 *
 *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
 *	Author: Jan Wieck, Afilias USA INC.
 *
 *	
 *-------------------------------------------------------------------------
 */
struct __yy_buffer
{
	YY_BUFFER_STATE	     buffer;				/* lexer buffer to restore on pop	*/
	long		         lineno;				/* line number to restore on pop	*/
	char               * fileName;				/* file name to restore on pop		*/
	struct __yy_buffer * prev;					/* pointer to previous stack frame	*/
} * yy_buffer = NULL;

typedef struct _symbol
{
    char           * name;						/* Name of symbol with % prepended	*/
	char           * value;						/* Value of symbol					*/
	struct _symbol * next;						/* Pointer to next symbol			*/
} symbol;

static symbol * symbols;						/* Head of list of symbols			*/

static char * getSymbol( const char * name );	/* Return a symbol's value (or NULL)*/
static void   addSymbol( char * str );			/* Add a new symbol					*/
static void   freeSymbols( void );              /* Free all symbols                 */
static void   pushBuffer( char * context );		/* Push a new lexer buffer on stack */
static void   popBuffer( void );				/* Pop previous lexer buffer		*/

extern char * current_file;
#line 40 "scan.l"

#include "libpq-fe.h"
#include "slonik.h"
#include "y.tab.h"


/*
quoted_ident	(\"[^\"]*\")+
identifier		({ident_start}{ident_cont}*|{quoted_ident})
*/
#line 872 "scan.c"

#define INITIAL 0
#define incl 1
#define define 2
#define IN_STRING 3

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (void );

int yyget_debug (void );

void yyset_debug (int debug_flag  );

YY_EXTRA_TYPE yyget_extra (void );

void yyset_extra (YY_EXTRA_TYPE user_defined  );

FILE *yyget_in (void );

void yyset_in  (FILE * in_str  );

FILE *yyget_out (void );

void yyset_out  (FILE * out_str  );

int yyget_leng (void );

char *yyget_text (void );

int yyget_lineno (void );

void yyset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (void );
#else
extern int yywrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 67 "scan.l"


	char   *instring_buffer = NULL;
	int     instring_length=0;
	int     instring_buf_length=0;

	BEGIN(INITIAL);

#line 1069 "scan.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE );
		}

		yy_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 387 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 891 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 75 "scan.l"
{ BEGIN(incl); }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 76 "scan.l"
{ BEGIN(define); }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 78 "scan.l"
{ return K_ADD;				}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 79 "scan.l"
{ return K_ADMIN;			}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 80 "scan.l"
{ return K_ALL;				}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 81 "scan.l"
{ return K_BACKUP;			}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 82 "scan.l"
{ return K_CLIENT;			}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 83 "scan.l"
{ return K_CLONE;			}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 84 "scan.l"
{ return K_CLUSTER;			}
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 85 "scan.l"
{ return K_COMMENT;			}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 86 "scan.l"
{ return K_CONFIG;			}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 87 "scan.l"
{ return K_CONFIRMED;		}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 88 "scan.l"
{ return K_CONNINFO;		}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 89 "scan.l"
{ return K_CONNRETRY;		}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 90 "scan.l"
{ return K_COPY;			}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 91 "scan.l"
{ return K_CREATE;			}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 92 "scan.l"
{ return K_DATE;			}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 93 "scan.l"
{ return K_DROP;			}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 94 "scan.l"
{ return K_ECHO;			}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 95 "scan.l"
{ return K_ERROR;			}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 96 "scan.l"
{ return K_EVENT;			}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 97 "scan.l"
{ return K_EXECUTE;			}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 98 "scan.l"
{ return K_EXIT;			}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 99 "scan.l"
{ return K_FAILOVER;		}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 100 "scan.l"
{ return K_FALSE;			}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 101 "scan.l"
{ return K_FILENAME;		}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 102 "scan.l"
{ return K_FINISH;			}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 103 "scan.l"
{ return K_FOR;				}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 104 "scan.l"
{ return K_DFORMAT;			}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 105 "scan.l"
{ return K_FORWARD;			}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 106 "scan.l"
{ return K_FULL;			}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 107 "scan.l"
{ return K_FULL;			}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 108 "scan.l"
{ return K_FUNCTIONS;		}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 109 "scan.l"
{ return K_ID;				}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 110 "scan.l"
{ return K_INIT;			}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 111 "scan.l"
{ return K_KEY;				}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 112 "scan.l"
{ return K_LISTEN;			}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 113 "scan.l"
{ return K_LOCK;			}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 114 "scan.l"
{ return K_LOG;				}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 115 "scan.l"
{ return K_MERGE;			}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 116 "scan.l"
{ return K_MOVE;			}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 117 "scan.l"
{ return K_NAME;			}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 118 "scan.l"
{ return K_NEW;				}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 119 "scan.l"
{ return K_NO;				}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 120 "scan.l"
{ return K_NODE;			}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 121 "scan.l"
{ return K_OFF;				}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 122 "scan.l"
{ return K_OLD;				}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 123 "scan.l"
{ return K_OMIT;			}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 124 "scan.l"
{ return K_ON;				}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 125 "scan.l"
{ return K_ONLY;			}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 126 "scan.l"
{ return K_ORIGIN;			}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 127 "scan.l"
{ return K_PATH;			}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 128 "scan.l"
{ return K_PREPARE;			}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 129 "scan.l"
{ return K_PROVIDER;		}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 130 "scan.l"
{ return K_QUALIFIED;		}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 131 "scan.l"
{ return K_RECEIVER;		}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 132 "scan.l"
{ return K_REPAIR;			}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 133 "scan.l"
{ return K_RESTART;			}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 134 "scan.l"
{ return K_RESUBSCRIBE;		}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 135 "scan.l"
{ return K_SCRIPT;			}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 136 "scan.l"
{ return K_SECONDS;         }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 137 "scan.l"
{ return K_SEQUENCE;		}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 138 "scan.l"
{ return K_SEQUENCES;		}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 139 "scan.l"
{ return K_SERVER;			}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 140 "scan.l"
{ return K_SET;				}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 141 "scan.l"
{ return K_SLEEP;			}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 142 "scan.l"
{ return K_SQL;				}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 143 "scan.l"
{ return K_STORE;			}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 144 "scan.l"
{ return K_SUBSCRIBE;		}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 145 "scan.l"
{ return K_SUCCESS;			}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 146 "scan.l"
{ return K_SWITCH;			}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 147 "scan.l"
{ return K_SYNC;			}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 148 "scan.l"
{ return K_TABLE;			}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 149 "scan.l"
{ return K_TABLES;			}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 150 "scan.l"
{ return K_TIMEOUT;			}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 151 "scan.l"
{ return K_TRUE;			}
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 152 "scan.l"
{ return K_TRY;				}
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 153 "scan.l"
{ return K_UNINSTALL;		}
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 154 "scan.l"
{ return K_UNLOCK;			}
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 155 "scan.l"
{ return K_UNSUBSCRIBE;		}
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 156 "scan.l"
{ return K_UPDATE;			}
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 157 "scan.l"
{ return K_WAIT;			}
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 158 "scan.l"
{ return K_YES;				}
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 159 "scan.l"
{ return T_NUMBER;			}
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 160 "scan.l"
{ return T_IDENT;			}
	YY_BREAK
case 86:
/* rule 86 can match eol */
YY_RULE_SETUP
#line 162 "scan.l"
;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 164 "scan.l"
{ 
			if( instring_buffer==NULL )
			{
				instring_buffer=malloc(256);
				if( instring_buffer == NULL)
				{
						fprintf(stderr,"insufficient memory\n");
						exit(1);


				}		
				instring_buf_length=256;
			}
			instring_length=0;
			instring_buffer[instring_length]=*yytext;
			BEGIN(IN_STRING);
		}
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 181 "scan.l"
{
				if (  instring_buf_length < instring_length + yyleng+1 )
				{
						instring_buffer=realloc(instring_buffer,instring_buf_length*2);
						instring_buf_length=instring_buf_length*2;
				}
				instring_buffer[instring_length++] = '\'';

				
		}
	YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
#line 191 "scan.l"
{ 
				if (  instring_buf_length < instring_length + yyleng+1 )
				{
						instring_buffer=realloc(instring_buffer,instring_buf_length*2);
						instring_buf_length=instring_buf_length*2;
				}
				strncpy(instring_buffer+instring_length,yytext,yyleng);
				instring_length+=yyleng;

				
		}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 202 "scan.l"
{
			instring_buffer[instring_length]='\0';
			yytext = instring_buffer;
			yyleng=instring_length;

			BEGIN(INITIAL);
			return T_LITERAL;
		}
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 210 "scan.l"
{ addSymbol( yytext ); BEGIN(INITIAL); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 212 "scan.l"
{ 
                  char * value = getSymbol( yytext );
                  
                  if( value )
                  {
                    pushBuffer( strdup( current_file ));
                    yy_scan_string(value );
                  }
                }
	YY_BREAK
case 93:
/* rule 93 can match eol */
YY_RULE_SETUP
#line 222 "scan.l"
{

                    char * fileName = strdup( yytext + 1 ); /* Skip '<' */

                    *strchr( fileName, '>' ) = '\0';        /* Trim '>' */

                    pushBuffer( fileName );

                    if(( yyin = fopen( fileName, "r" )) == NULL )
                    {
                        fprintf( stderr,  "Include file (%s) not found\n", fileName );
                        exit( 1 );
                    }
                 
                    yy_switch_to_buffer(yy_create_buffer(yyin,YY_BUF_SIZE ));

                    BEGIN(INITIAL);
                }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(incl):
case YY_STATE_EOF(define):
case YY_STATE_EOF(IN_STRING):
#line 241 "scan.l"
{
                    if( yy_buffer == NULL )
                        yyterminate();
                    else
                        popBuffer();
                }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 248 "scan.l"
;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 250 "scan.l"
{ return yytext[0];				}
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 252 "scan.l"
ECHO;
	YY_BREAK
#line 1727 "scan.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 387 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 387 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 386);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		   
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE );
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file );
	yy_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf  );

	yyfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr )
{
    
	return yy_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
        
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void yyset_lineno (int  line_number )
{
    
    yylineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str )
{
        yyin = in_str ;
}

void yyset_out (FILE *  out_str )
{
        yyout = out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  bdebug )
{
        yy_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr )
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 252 "scan.l"



void
scan_new_input_file(FILE *in)
{
	SlonDString		ds;
	char			buf[8192];
	int				len;

	if (YY_CURRENT_BUFFER)
		yy_delete_buffer(YY_CURRENT_BUFFER);

	dstring_init(&ds);
	while ((len = fread(&buf, 1, 8192, in)) > 0)
	{
		dstring_nappend(&ds, buf, len);
	}
	dstring_terminate(&ds);
	yy_switch_to_buffer(yy_scan_string(dstring_data(&ds)));

	dstring_free(&ds);

    freeSymbols();
}

static void pushBuffer( char * context )
{
	struct __yy_buffer * yb = malloc( sizeof( *yb ));

	yb->buffer   = YY_CURRENT_BUFFER;
	yb->lineno   = yylineno;
	yb->fileName = strdup( current_file );
	yb->prev     = yy_buffer;

	yy_buffer = yb;

	current_file = context;
	yylineno     = 1;
}

static void popBuffer( void )
{
	struct __yy_buffer * yb = yy_buffer;

	if( yyin != NULL )
		fclose( yyin );
	
	yy_delete_buffer(YY_CURRENT_BUFFER );
	yy_switch_to_buffer(yy_buffer->buffer );
	
	free( current_file );
	
	current_file = yy_buffer->fileName;
	yylineno     = yy_buffer->lineno;
	
	yy_buffer = yy_buffer->prev;
	
	free( yb );
}

static void addSymbol( char * str )
{
	char   * name  = str;
	char   * value = str;
	symbol * sym   = NULL;

	while( *value != ' ' && *value != '\t' )
		value++;

	*(value++) = '\0';

	while( *value == ' ' || *value == '\t' )
		value++;

	value[strlen(value) - 1 ] = '\0';

	sym = malloc( sizeof( *sym ));
	sym->value = strdup( value );
	sym->next  = NULL;
	
	/* Store the symbol name in searchable form  with a leading @ */

	sym->name  = malloc( strlen( name ) + 1 + 1 );

	sym->name[0] = '@';
	strcpy( sym->name+1, name );

	if( symbols != NULL )
		sym->next = symbols;

	symbols = sym;
}

static char * getSymbol( const char * name )
{
	symbol * sym;

	for( sym = symbols; sym; sym = sym->next )
	{
		if( strcmp( name, sym->name ) == 0 )
			return( sym->value );
	}

	return( NULL );
}

static void freeSymbols( void )
{
	symbol * sym = symbols;

	while( sym )
	{
		symbol * victim = sym;

		sym = sym->next;

		free( victim->name );
		free( victim->value );
		free( victim );
	}

	symbols = NULL;
}
/*
 * Local Variables:
 *  tab-width: 4
 *  c-indent-level: 4
 *  c-basic-offset: 4
 * End:
 */

